@@ -24,12 +24,12 @@
  *                                                                  *
 \********************************************************************/
 
-
 #include "config.h"
 
 #include <sys/types.h>
 #include <unistd.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n.h>
 
 #include <qof.h>
 #include <unittest-support.h>
@@ -595,6 +595,42 @@ test_dbi_business_store_and_reload (Fixture *fixture, gconstpointer pData)
     qof_session_destroy (session_3);
 }
 
+static void
+test_adjust_sql_options_string (void)
+{
+    gchar *adjusted_str;
+    const char* in[] = {
+        "NO_ZERO_DATE",
+        "NO_ZERO_DATE,something_else",
+        "something,NO_ZERO_DATE",
+        "something,NO_ZERO_DATE,something_else",
+        "NO_ZERO_DATExx",
+        "NO_ZERO_DATExx,something_ else",
+        "something,NO_ZERO_DATExx",
+        "something,NO_ZERO_DATExx,something_ else",
+        "fred,jim,john"
+    };
+    const char* out[] = {
+        "",
+        "something_else",
+        "something",
+        "something,something_else",
+        "NO_ZERO_DATExx",
+        "NO_ZERO_DATExx,something_ else",
+        "something,NO_ZERO_DATExx",
+        "something,NO_ZERO_DATExx,something_ else",
+        "fred,jim,john"
+    };
+
+    size_t i;
+    for (i = 0; i < sizeof(in) / sizeof(gchar*); i++)
+    {
+        gchar *adjusted_str = adjust_sql_options_string (in[i]);
+        g_assert_cmpstr (out[i],==,adjusted_str);
+        g_free (adjusted_str);
+    }
+}
+
 static void
 create_dbi_test_suite (gchar *dbm_name, gchar *url)
 {
@@ -640,4 +676,6 @@ test_suite_gnc_backend_dbi (void)
         create_dbi_test_suite ("postgres", TEST_PGSQL_URL);
     }
 
+    GNC_TEST_ADD_FUNC( suitename, "adjust sql options string localtime", 
+        test_adjust_sql_options_string );
 }
